/*******************************************************************************
* File Name: BZ.h
* Version 2.10
*
* Description:
*  This file provides constants and parameter values for the BZ
*  component.
*
* Note:
*  None
*
********************************************************************************
* Copyright 2013-2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_TCPWM_BZ_H)
#define CY_TCPWM_BZ_H


#include "CyLib.h"
#include "cytypes.h"
#include "cyfitter.h"


/*******************************************************************************
* Internal Type defines
*******************************************************************************/

/* Structure to save state before go to sleep */
typedef struct
{
    uint8  enableState;
} BZ_BACKUP_STRUCT;


/*******************************************************************************
* Variables
*******************************************************************************/
extern uint8  BZ_initVar;


/***************************************
*   Conditional Compilation Parameters
****************************************/

#define BZ_CY_TCPWM_V2                    (CYIPBLOCK_m0s8tcpwm_VERSION == 2u)
#define BZ_CY_TCPWM_4000                  (CY_PSOC4_4000)

/* TCPWM Configuration */
#define BZ_CONFIG                         (7lu)

/* Quad Mode */
/* Parameters */
#define BZ_QUAD_ENCODING_MODES            (0lu)
#define BZ_QUAD_AUTO_START                (1lu)

/* Signal modes */
#define BZ_QUAD_INDEX_SIGNAL_MODE         (0lu)
#define BZ_QUAD_PHIA_SIGNAL_MODE          (3lu)
#define BZ_QUAD_PHIB_SIGNAL_MODE          (3lu)
#define BZ_QUAD_STOP_SIGNAL_MODE          (0lu)

/* Signal present */
#define BZ_QUAD_INDEX_SIGNAL_PRESENT      (0lu)
#define BZ_QUAD_STOP_SIGNAL_PRESENT       (0lu)

/* Interrupt Mask */
#define BZ_QUAD_INTERRUPT_MASK            (1lu)

/* Timer/Counter Mode */
/* Parameters */
#define BZ_TC_RUN_MODE                    (0lu)
#define BZ_TC_COUNTER_MODE                (0lu)
#define BZ_TC_COMP_CAP_MODE               (2lu)
#define BZ_TC_PRESCALER                   (0lu)

/* Signal modes */
#define BZ_TC_RELOAD_SIGNAL_MODE          (0lu)
#define BZ_TC_COUNT_SIGNAL_MODE           (3lu)
#define BZ_TC_START_SIGNAL_MODE           (0lu)
#define BZ_TC_STOP_SIGNAL_MODE            (0lu)
#define BZ_TC_CAPTURE_SIGNAL_MODE         (0lu)

/* Signal present */
#define BZ_TC_RELOAD_SIGNAL_PRESENT       (0lu)
#define BZ_TC_COUNT_SIGNAL_PRESENT        (0lu)
#define BZ_TC_START_SIGNAL_PRESENT        (0lu)
#define BZ_TC_STOP_SIGNAL_PRESENT         (0lu)
#define BZ_TC_CAPTURE_SIGNAL_PRESENT      (0lu)

/* Interrupt Mask */
#define BZ_TC_INTERRUPT_MASK              (1lu)

/* PWM Mode */
/* Parameters */
#define BZ_PWM_KILL_EVENT                 (0lu)
#define BZ_PWM_STOP_EVENT                 (0lu)
#define BZ_PWM_MODE                       (4lu)
#define BZ_PWM_OUT_N_INVERT               (0lu)
#define BZ_PWM_OUT_INVERT                 (0lu)
#define BZ_PWM_ALIGN                      (0lu)
#define BZ_PWM_RUN_MODE                   (0lu)
#define BZ_PWM_DEAD_TIME_CYCLE            (0lu)
#define BZ_PWM_PRESCALER                  (0lu)

/* Signal modes */
#define BZ_PWM_RELOAD_SIGNAL_MODE         (0lu)
#define BZ_PWM_COUNT_SIGNAL_MODE          (3lu)
#define BZ_PWM_START_SIGNAL_MODE          (0lu)
#define BZ_PWM_STOP_SIGNAL_MODE           (0lu)
#define BZ_PWM_SWITCH_SIGNAL_MODE         (0lu)

/* Signal present */
#define BZ_PWM_RELOAD_SIGNAL_PRESENT      (0lu)
#define BZ_PWM_COUNT_SIGNAL_PRESENT       (0lu)
#define BZ_PWM_START_SIGNAL_PRESENT       (0lu)
#define BZ_PWM_STOP_SIGNAL_PRESENT        (0lu)
#define BZ_PWM_SWITCH_SIGNAL_PRESENT      (0lu)

/* Interrupt Mask */
#define BZ_PWM_INTERRUPT_MASK             (1lu)


/***************************************
*    Initial Parameter Constants
***************************************/

/* Timer/Counter Mode */
#define BZ_TC_PERIOD_VALUE                (65535lu)
#define BZ_TC_COMPARE_VALUE               (65535lu)
#define BZ_TC_COMPARE_BUF_VALUE           (65535lu)
#define BZ_TC_COMPARE_SWAP                (0lu)

/* PWM Mode */
#define BZ_PWM_PERIOD_VALUE               (100lu)
#define BZ_PWM_PERIOD_BUF_VALUE           (65535lu)
#define BZ_PWM_PERIOD_SWAP                (0lu)
#define BZ_PWM_COMPARE_VALUE              (50lu)
#define BZ_PWM_COMPARE_BUF_VALUE          (65535lu)
#define BZ_PWM_COMPARE_SWAP               (0lu)


/***************************************
*    Enumerated Types and Parameters
***************************************/

#define BZ__LEFT 0
#define BZ__RIGHT 1
#define BZ__CENTER 2
#define BZ__ASYMMETRIC 3

#define BZ__X1 0
#define BZ__X2 1
#define BZ__X4 2

#define BZ__PWM 4
#define BZ__PWM_DT 5
#define BZ__PWM_PR 6

#define BZ__INVERSE 1
#define BZ__DIRECT 0

#define BZ__CAPTURE 2
#define BZ__COMPARE 0

#define BZ__TRIG_LEVEL 3
#define BZ__TRIG_RISING 0
#define BZ__TRIG_FALLING 1
#define BZ__TRIG_BOTH 2

#define BZ__INTR_MASK_TC 1
#define BZ__INTR_MASK_CC_MATCH 2
#define BZ__INTR_MASK_NONE 0
#define BZ__INTR_MASK_TC_CC 3

#define BZ__UNCONFIG 8
#define BZ__TIMER 1
#define BZ__QUAD 3
#define BZ__PWM_SEL 7

#define BZ__COUNT_UP 0
#define BZ__COUNT_DOWN 1
#define BZ__COUNT_UPDOWN0 2
#define BZ__COUNT_UPDOWN1 3


/* Prescaler */
#define BZ_PRESCALE_DIVBY1                ((uint32)(0u << BZ_PRESCALER_SHIFT))
#define BZ_PRESCALE_DIVBY2                ((uint32)(1u << BZ_PRESCALER_SHIFT))
#define BZ_PRESCALE_DIVBY4                ((uint32)(2u << BZ_PRESCALER_SHIFT))
#define BZ_PRESCALE_DIVBY8                ((uint32)(3u << BZ_PRESCALER_SHIFT))
#define BZ_PRESCALE_DIVBY16               ((uint32)(4u << BZ_PRESCALER_SHIFT))
#define BZ_PRESCALE_DIVBY32               ((uint32)(5u << BZ_PRESCALER_SHIFT))
#define BZ_PRESCALE_DIVBY64               ((uint32)(6u << BZ_PRESCALER_SHIFT))
#define BZ_PRESCALE_DIVBY128              ((uint32)(7u << BZ_PRESCALER_SHIFT))

/* TCPWM set modes */
#define BZ_MODE_TIMER_COMPARE             ((uint32)(BZ__COMPARE         <<  \
                                                                  BZ_MODE_SHIFT))
#define BZ_MODE_TIMER_CAPTURE             ((uint32)(BZ__CAPTURE         <<  \
                                                                  BZ_MODE_SHIFT))
#define BZ_MODE_QUAD                      ((uint32)(BZ__QUAD            <<  \
                                                                  BZ_MODE_SHIFT))
#define BZ_MODE_PWM                       ((uint32)(BZ__PWM             <<  \
                                                                  BZ_MODE_SHIFT))
#define BZ_MODE_PWM_DT                    ((uint32)(BZ__PWM_DT          <<  \
                                                                  BZ_MODE_SHIFT))
#define BZ_MODE_PWM_PR                    ((uint32)(BZ__PWM_PR          <<  \
                                                                  BZ_MODE_SHIFT))

/* Quad Modes */
#define BZ_MODE_X1                        ((uint32)(BZ__X1              <<  \
                                                                  BZ_QUAD_MODE_SHIFT))
#define BZ_MODE_X2                        ((uint32)(BZ__X2              <<  \
                                                                  BZ_QUAD_MODE_SHIFT))
#define BZ_MODE_X4                        ((uint32)(BZ__X4              <<  \
                                                                  BZ_QUAD_MODE_SHIFT))

/* Counter modes */
#define BZ_COUNT_UP                       ((uint32)(BZ__COUNT_UP        <<  \
                                                                  BZ_UPDOWN_SHIFT))
#define BZ_COUNT_DOWN                     ((uint32)(BZ__COUNT_DOWN      <<  \
                                                                  BZ_UPDOWN_SHIFT))
#define BZ_COUNT_UPDOWN0                  ((uint32)(BZ__COUNT_UPDOWN0   <<  \
                                                                  BZ_UPDOWN_SHIFT))
#define BZ_COUNT_UPDOWN1                  ((uint32)(BZ__COUNT_UPDOWN1   <<  \
                                                                  BZ_UPDOWN_SHIFT))

/* PWM output invert */
#define BZ_INVERT_LINE                    ((uint32)(BZ__INVERSE         <<  \
                                                                  BZ_INV_OUT_SHIFT))
#define BZ_INVERT_LINE_N                  ((uint32)(BZ__INVERSE         <<  \
                                                                  BZ_INV_COMPL_OUT_SHIFT))

/* Trigger modes */
#define BZ_TRIG_RISING                    ((uint32)BZ__TRIG_RISING)
#define BZ_TRIG_FALLING                   ((uint32)BZ__TRIG_FALLING)
#define BZ_TRIG_BOTH                      ((uint32)BZ__TRIG_BOTH)
#define BZ_TRIG_LEVEL                     ((uint32)BZ__TRIG_LEVEL)

/* Interrupt mask */
#define BZ_INTR_MASK_TC                   ((uint32)BZ__INTR_MASK_TC)
#define BZ_INTR_MASK_CC_MATCH             ((uint32)BZ__INTR_MASK_CC_MATCH)

/* PWM Output Controls */
#define BZ_CC_MATCH_SET                   (0x00u)
#define BZ_CC_MATCH_CLEAR                 (0x01u)
#define BZ_CC_MATCH_INVERT                (0x02u)
#define BZ_CC_MATCH_NO_CHANGE             (0x03u)
#define BZ_OVERLOW_SET                    (0x00u)
#define BZ_OVERLOW_CLEAR                  (0x04u)
#define BZ_OVERLOW_INVERT                 (0x08u)
#define BZ_OVERLOW_NO_CHANGE              (0x0Cu)
#define BZ_UNDERFLOW_SET                  (0x00u)
#define BZ_UNDERFLOW_CLEAR                (0x10u)
#define BZ_UNDERFLOW_INVERT               (0x20u)
#define BZ_UNDERFLOW_NO_CHANGE            (0x30u)

/* PWM Align */
#define BZ_PWM_MODE_LEFT                  (BZ_CC_MATCH_CLEAR        |   \
                                                         BZ_OVERLOW_SET           |   \
                                                         BZ_UNDERFLOW_NO_CHANGE)
#define BZ_PWM_MODE_RIGHT                 (BZ_CC_MATCH_SET          |   \
                                                         BZ_OVERLOW_NO_CHANGE     |   \
                                                         BZ_UNDERFLOW_CLEAR)
#define BZ_PWM_MODE_ASYM                  (BZ_CC_MATCH_INVERT       |   \
                                                         BZ_OVERLOW_SET           |   \
                                                         BZ_UNDERFLOW_CLEAR)

#if (BZ_CY_TCPWM_V2)
    #if(BZ_CY_TCPWM_4000)
        #define BZ_PWM_MODE_CENTER                (BZ_CC_MATCH_INVERT       |   \
                                                                 BZ_OVERLOW_NO_CHANGE     |   \
                                                                 BZ_UNDERFLOW_CLEAR)
    #else
        #define BZ_PWM_MODE_CENTER                (BZ_CC_MATCH_INVERT       |   \
                                                                 BZ_OVERLOW_SET           |   \
                                                                 BZ_UNDERFLOW_CLEAR)
    #endif /* (BZ_CY_TCPWM_4000) */
#else
    #define BZ_PWM_MODE_CENTER                (BZ_CC_MATCH_INVERT       |   \
                                                             BZ_OVERLOW_NO_CHANGE     |   \
                                                             BZ_UNDERFLOW_CLEAR)
#endif /* (BZ_CY_TCPWM_NEW) */

/* Command operations without condition */
#define BZ_CMD_CAPTURE                    (0u)
#define BZ_CMD_RELOAD                     (8u)
#define BZ_CMD_STOP                       (16u)
#define BZ_CMD_START                      (24u)

/* Status */
#define BZ_STATUS_DOWN                    (1u)
#define BZ_STATUS_RUNNING                 (2u)


/***************************************
*        Function Prototypes
****************************************/

void   BZ_Init(void);
void   BZ_Enable(void);
void   BZ_Start(void);
void   BZ_Stop(void);

void   BZ_SetMode(uint32 mode);
void   BZ_SetCounterMode(uint32 counterMode);
void   BZ_SetPWMMode(uint32 modeMask);
void   BZ_SetQDMode(uint32 qdMode);

void   BZ_SetPrescaler(uint32 prescaler);
void   BZ_TriggerCommand(uint32 mask, uint32 command);
void   BZ_SetOneShot(uint32 oneShotEnable);
uint32 BZ_ReadStatus(void);

void   BZ_SetPWMSyncKill(uint32 syncKillEnable);
void   BZ_SetPWMStopOnKill(uint32 stopOnKillEnable);
void   BZ_SetPWMDeadTime(uint32 deadTime);
void   BZ_SetPWMInvert(uint32 mask);

void   BZ_SetInterruptMode(uint32 interruptMask);
uint32 BZ_GetInterruptSourceMasked(void);
uint32 BZ_GetInterruptSource(void);
void   BZ_ClearInterrupt(uint32 interruptMask);
void   BZ_SetInterrupt(uint32 interruptMask);

void   BZ_WriteCounter(uint32 count);
uint32 BZ_ReadCounter(void);

uint32 BZ_ReadCapture(void);
uint32 BZ_ReadCaptureBuf(void);

void   BZ_WritePeriod(uint32 period);
uint32 BZ_ReadPeriod(void);
void   BZ_WritePeriodBuf(uint32 periodBuf);
uint32 BZ_ReadPeriodBuf(void);

void   BZ_WriteCompare(uint32 compare);
uint32 BZ_ReadCompare(void);
void   BZ_WriteCompareBuf(uint32 compareBuf);
uint32 BZ_ReadCompareBuf(void);

void   BZ_SetPeriodSwap(uint32 swapEnable);
void   BZ_SetCompareSwap(uint32 swapEnable);

void   BZ_SetCaptureMode(uint32 triggerMode);
void   BZ_SetReloadMode(uint32 triggerMode);
void   BZ_SetStartMode(uint32 triggerMode);
void   BZ_SetStopMode(uint32 triggerMode);
void   BZ_SetCountMode(uint32 triggerMode);

void   BZ_SaveConfig(void);
void   BZ_RestoreConfig(void);
void   BZ_Sleep(void);
void   BZ_Wakeup(void);


/***************************************
*             Registers
***************************************/

#define BZ_BLOCK_CONTROL_REG              (*(reg32 *) BZ_cy_m0s8_tcpwm_1__TCPWM_CTRL )
#define BZ_BLOCK_CONTROL_PTR              ( (reg32 *) BZ_cy_m0s8_tcpwm_1__TCPWM_CTRL )
#define BZ_COMMAND_REG                    (*(reg32 *) BZ_cy_m0s8_tcpwm_1__TCPWM_CMD )
#define BZ_COMMAND_PTR                    ( (reg32 *) BZ_cy_m0s8_tcpwm_1__TCPWM_CMD )
#define BZ_INTRRUPT_CAUSE_REG             (*(reg32 *) BZ_cy_m0s8_tcpwm_1__TCPWM_INTR_CAUSE )
#define BZ_INTRRUPT_CAUSE_PTR             ( (reg32 *) BZ_cy_m0s8_tcpwm_1__TCPWM_INTR_CAUSE )
#define BZ_CONTROL_REG                    (*(reg32 *) BZ_cy_m0s8_tcpwm_1__CTRL )
#define BZ_CONTROL_PTR                    ( (reg32 *) BZ_cy_m0s8_tcpwm_1__CTRL )
#define BZ_STATUS_REG                     (*(reg32 *) BZ_cy_m0s8_tcpwm_1__STATUS )
#define BZ_STATUS_PTR                     ( (reg32 *) BZ_cy_m0s8_tcpwm_1__STATUS )
#define BZ_COUNTER_REG                    (*(reg32 *) BZ_cy_m0s8_tcpwm_1__COUNTER )
#define BZ_COUNTER_PTR                    ( (reg32 *) BZ_cy_m0s8_tcpwm_1__COUNTER )
#define BZ_COMP_CAP_REG                   (*(reg32 *) BZ_cy_m0s8_tcpwm_1__CC )
#define BZ_COMP_CAP_PTR                   ( (reg32 *) BZ_cy_m0s8_tcpwm_1__CC )
#define BZ_COMP_CAP_BUF_REG               (*(reg32 *) BZ_cy_m0s8_tcpwm_1__CC_BUFF )
#define BZ_COMP_CAP_BUF_PTR               ( (reg32 *) BZ_cy_m0s8_tcpwm_1__CC_BUFF )
#define BZ_PERIOD_REG                     (*(reg32 *) BZ_cy_m0s8_tcpwm_1__PERIOD )
#define BZ_PERIOD_PTR                     ( (reg32 *) BZ_cy_m0s8_tcpwm_1__PERIOD )
#define BZ_PERIOD_BUF_REG                 (*(reg32 *) BZ_cy_m0s8_tcpwm_1__PERIOD_BUFF )
#define BZ_PERIOD_BUF_PTR                 ( (reg32 *) BZ_cy_m0s8_tcpwm_1__PERIOD_BUFF )
#define BZ_TRIG_CONTROL0_REG              (*(reg32 *) BZ_cy_m0s8_tcpwm_1__TR_CTRL0 )
#define BZ_TRIG_CONTROL0_PTR              ( (reg32 *) BZ_cy_m0s8_tcpwm_1__TR_CTRL0 )
#define BZ_TRIG_CONTROL1_REG              (*(reg32 *) BZ_cy_m0s8_tcpwm_1__TR_CTRL1 )
#define BZ_TRIG_CONTROL1_PTR              ( (reg32 *) BZ_cy_m0s8_tcpwm_1__TR_CTRL1 )
#define BZ_TRIG_CONTROL2_REG              (*(reg32 *) BZ_cy_m0s8_tcpwm_1__TR_CTRL2 )
#define BZ_TRIG_CONTROL2_PTR              ( (reg32 *) BZ_cy_m0s8_tcpwm_1__TR_CTRL2 )
#define BZ_INTERRUPT_REQ_REG              (*(reg32 *) BZ_cy_m0s8_tcpwm_1__INTR )
#define BZ_INTERRUPT_REQ_PTR              ( (reg32 *) BZ_cy_m0s8_tcpwm_1__INTR )
#define BZ_INTERRUPT_SET_REG              (*(reg32 *) BZ_cy_m0s8_tcpwm_1__INTR_SET )
#define BZ_INTERRUPT_SET_PTR              ( (reg32 *) BZ_cy_m0s8_tcpwm_1__INTR_SET )
#define BZ_INTERRUPT_MASK_REG             (*(reg32 *) BZ_cy_m0s8_tcpwm_1__INTR_MASK )
#define BZ_INTERRUPT_MASK_PTR             ( (reg32 *) BZ_cy_m0s8_tcpwm_1__INTR_MASK )
#define BZ_INTERRUPT_MASKED_REG           (*(reg32 *) BZ_cy_m0s8_tcpwm_1__INTR_MASKED )
#define BZ_INTERRUPT_MASKED_PTR           ( (reg32 *) BZ_cy_m0s8_tcpwm_1__INTR_MASKED )


/***************************************
*       Registers Constants
***************************************/

/* Mask */
#define BZ_MASK                           ((uint32)BZ_cy_m0s8_tcpwm_1__TCPWM_CTRL_MASK)

/* Shift constants for control register */
#define BZ_RELOAD_CC_SHIFT                (0u)
#define BZ_RELOAD_PERIOD_SHIFT            (1u)
#define BZ_PWM_SYNC_KILL_SHIFT            (2u)
#define BZ_PWM_STOP_KILL_SHIFT            (3u)
#define BZ_PRESCALER_SHIFT                (8u)
#define BZ_UPDOWN_SHIFT                   (16u)
#define BZ_ONESHOT_SHIFT                  (18u)
#define BZ_QUAD_MODE_SHIFT                (20u)
#define BZ_INV_OUT_SHIFT                  (20u)
#define BZ_INV_COMPL_OUT_SHIFT            (21u)
#define BZ_MODE_SHIFT                     (24u)

/* Mask constants for control register */
#define BZ_RELOAD_CC_MASK                 ((uint32)(BZ_1BIT_MASK        <<  \
                                                                            BZ_RELOAD_CC_SHIFT))
#define BZ_RELOAD_PERIOD_MASK             ((uint32)(BZ_1BIT_MASK        <<  \
                                                                            BZ_RELOAD_PERIOD_SHIFT))
#define BZ_PWM_SYNC_KILL_MASK             ((uint32)(BZ_1BIT_MASK        <<  \
                                                                            BZ_PWM_SYNC_KILL_SHIFT))
#define BZ_PWM_STOP_KILL_MASK             ((uint32)(BZ_1BIT_MASK        <<  \
                                                                            BZ_PWM_STOP_KILL_SHIFT))
#define BZ_PRESCALER_MASK                 ((uint32)(BZ_8BIT_MASK        <<  \
                                                                            BZ_PRESCALER_SHIFT))
#define BZ_UPDOWN_MASK                    ((uint32)(BZ_2BIT_MASK        <<  \
                                                                            BZ_UPDOWN_SHIFT))
#define BZ_ONESHOT_MASK                   ((uint32)(BZ_1BIT_MASK        <<  \
                                                                            BZ_ONESHOT_SHIFT))
#define BZ_QUAD_MODE_MASK                 ((uint32)(BZ_3BIT_MASK        <<  \
                                                                            BZ_QUAD_MODE_SHIFT))
#define BZ_INV_OUT_MASK                   ((uint32)(BZ_2BIT_MASK        <<  \
                                                                            BZ_INV_OUT_SHIFT))
#define BZ_MODE_MASK                      ((uint32)(BZ_3BIT_MASK        <<  \
                                                                            BZ_MODE_SHIFT))

/* Shift constants for trigger control register 1 */
#define BZ_CAPTURE_SHIFT                  (0u)
#define BZ_COUNT_SHIFT                    (2u)
#define BZ_RELOAD_SHIFT                   (4u)
#define BZ_STOP_SHIFT                     (6u)
#define BZ_START_SHIFT                    (8u)

/* Mask constants for trigger control register 1 */
#define BZ_CAPTURE_MASK                   ((uint32)(BZ_2BIT_MASK        <<  \
                                                                  BZ_CAPTURE_SHIFT))
#define BZ_COUNT_MASK                     ((uint32)(BZ_2BIT_MASK        <<  \
                                                                  BZ_COUNT_SHIFT))
#define BZ_RELOAD_MASK                    ((uint32)(BZ_2BIT_MASK        <<  \
                                                                  BZ_RELOAD_SHIFT))
#define BZ_STOP_MASK                      ((uint32)(BZ_2BIT_MASK        <<  \
                                                                  BZ_STOP_SHIFT))
#define BZ_START_MASK                     ((uint32)(BZ_2BIT_MASK        <<  \
                                                                  BZ_START_SHIFT))

/* MASK */
#define BZ_1BIT_MASK                      ((uint32)0x01u)
#define BZ_2BIT_MASK                      ((uint32)0x03u)
#define BZ_3BIT_MASK                      ((uint32)0x07u)
#define BZ_6BIT_MASK                      ((uint32)0x3Fu)
#define BZ_8BIT_MASK                      ((uint32)0xFFu)
#define BZ_16BIT_MASK                     ((uint32)0xFFFFu)

/* Shift constant for status register */
#define BZ_RUNNING_STATUS_SHIFT           (30u)


/***************************************
*    Initial Constants
***************************************/

#define BZ_CTRL_QUAD_BASE_CONFIG                                                          \
        (((uint32)(BZ_QUAD_ENCODING_MODES     << BZ_QUAD_MODE_SHIFT))       |\
         ((uint32)(BZ_CONFIG                  << BZ_MODE_SHIFT)))

#define BZ_CTRL_PWM_BASE_CONFIG                                                           \
        (((uint32)(BZ_PWM_STOP_EVENT          << BZ_PWM_STOP_KILL_SHIFT))   |\
         ((uint32)(BZ_PWM_OUT_INVERT          << BZ_INV_OUT_SHIFT))         |\
         ((uint32)(BZ_PWM_OUT_N_INVERT        << BZ_INV_COMPL_OUT_SHIFT))   |\
         ((uint32)(BZ_PWM_MODE                << BZ_MODE_SHIFT)))

#define BZ_CTRL_PWM_RUN_MODE                                                              \
            ((uint32)(BZ_PWM_RUN_MODE         << BZ_ONESHOT_SHIFT))
            
#define BZ_CTRL_PWM_ALIGN                                                                 \
            ((uint32)(BZ_PWM_ALIGN            << BZ_UPDOWN_SHIFT))

#define BZ_CTRL_PWM_KILL_EVENT                                                            \
             ((uint32)(BZ_PWM_KILL_EVENT      << BZ_PWM_SYNC_KILL_SHIFT))

#define BZ_CTRL_PWM_DEAD_TIME_CYCLE                                                       \
            ((uint32)(BZ_PWM_DEAD_TIME_CYCLE  << BZ_PRESCALER_SHIFT))

#define BZ_CTRL_PWM_PRESCALER                                                             \
            ((uint32)(BZ_PWM_PRESCALER        << BZ_PRESCALER_SHIFT))

#define BZ_CTRL_TIMER_BASE_CONFIG                                                         \
        (((uint32)(BZ_TC_PRESCALER            << BZ_PRESCALER_SHIFT))       |\
         ((uint32)(BZ_TC_COUNTER_MODE         << BZ_UPDOWN_SHIFT))          |\
         ((uint32)(BZ_TC_RUN_MODE             << BZ_ONESHOT_SHIFT))         |\
         ((uint32)(BZ_TC_COMP_CAP_MODE        << BZ_MODE_SHIFT)))
        
#define BZ_QUAD_SIGNALS_MODES                                                             \
        (((uint32)(BZ_QUAD_PHIA_SIGNAL_MODE   << BZ_COUNT_SHIFT))           |\
         ((uint32)(BZ_QUAD_INDEX_SIGNAL_MODE  << BZ_RELOAD_SHIFT))          |\
         ((uint32)(BZ_QUAD_STOP_SIGNAL_MODE   << BZ_STOP_SHIFT))            |\
         ((uint32)(BZ_QUAD_PHIB_SIGNAL_MODE   << BZ_START_SHIFT)))

#define BZ_PWM_SIGNALS_MODES                                                              \
        (((uint32)(BZ_PWM_SWITCH_SIGNAL_MODE  << BZ_CAPTURE_SHIFT))         |\
         ((uint32)(BZ_PWM_COUNT_SIGNAL_MODE   << BZ_COUNT_SHIFT))           |\
         ((uint32)(BZ_PWM_RELOAD_SIGNAL_MODE  << BZ_RELOAD_SHIFT))          |\
         ((uint32)(BZ_PWM_STOP_SIGNAL_MODE    << BZ_STOP_SHIFT))            |\
         ((uint32)(BZ_PWM_START_SIGNAL_MODE   << BZ_START_SHIFT)))

#define BZ_TIMER_SIGNALS_MODES                                                            \
        (((uint32)(BZ_TC_CAPTURE_SIGNAL_MODE  << BZ_CAPTURE_SHIFT))         |\
         ((uint32)(BZ_TC_COUNT_SIGNAL_MODE    << BZ_COUNT_SHIFT))           |\
         ((uint32)(BZ_TC_RELOAD_SIGNAL_MODE   << BZ_RELOAD_SHIFT))          |\
         ((uint32)(BZ_TC_STOP_SIGNAL_MODE     << BZ_STOP_SHIFT))            |\
         ((uint32)(BZ_TC_START_SIGNAL_MODE    << BZ_START_SHIFT)))
        
#define BZ_TIMER_UPDOWN_CNT_USED                                                          \
                ((BZ__COUNT_UPDOWN0 == BZ_TC_COUNTER_MODE)                  ||\
                 (BZ__COUNT_UPDOWN1 == BZ_TC_COUNTER_MODE))

#define BZ_PWM_UPDOWN_CNT_USED                                                            \
                ((BZ__CENTER == BZ_PWM_ALIGN)                               ||\
                 (BZ__ASYMMETRIC == BZ_PWM_ALIGN))               
        
#define BZ_PWM_PR_INIT_VALUE              (1u)
#define BZ_QUAD_PERIOD_INIT_VALUE         (0x8000u)



#endif /* End CY_TCPWM_BZ_H */

/* [] END OF FILE */
